on_access_click

Function on_access_click 

pub fn on_access_click(
    child: impl IntoUiNode,
    handler: Handler<AccessClickArgs>,
) -> UiNode
Access requested a click.

Note that the normal click event is already triggered by this event.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.