pub fn on_access_increment(
child: impl IntoUiNode,
handler: Handler<AccessIncrementArgs>,
) -> UiNodeExpand description
Access requested to increment or decrement the widget value by steps.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.