on_access_number

Function on_access_number 

pub fn on_access_number(
    child: impl IntoUiNode,
    handler: Handler<AccessNumberArgs>,
) -> UiNode
Access requested a number input.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.