on_access_text

Function on_access_text 

pub fn on_access_text(
    child: impl IntoUiNode,
    handler: Handler<AccessTextArgs>,
) -> UiNode
Access requested a text input/replace.

Note that the text widget already handles this event.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.