on_access_tooltip

Function on_access_tooltip 

pub fn on_access_tooltip(
    child: impl IntoUiNode,
    handler: Handler<AccessToolTipArgs>,
) -> UiNode
Access requested to show or hide the widget’s tooltip.

Note that the tooltip property already handles this event.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.