on_pre_access_click

Function on_pre_access_click 

pub fn on_pre_access_click(
    child: impl IntoUiNode,
    handler: Handler<AccessClickArgs>,
) -> UiNode
Access requested a click.

Note that the normal click event is already triggered by this event.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.