pub fn on_pre_access_number( child: impl IntoUiNode, handler: Handler<AccessNumberArgs>, ) -> UiNode
Access requested a number input.
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident