pub fn on_pre_access_text( child: impl IntoUiNode, handler: Handler<AccessTextArgs>, ) -> UiNode
Access requested a text input/replace.
Note that the text widget already handles this event.
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident