pub fn on_access_text(
child: impl IntoUiNode,
handler: Handler<AccessTextArgs>,
) -> UiNodeExpand description
Access requested a text input/replace.
Note that the text widget already handles this event.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.