on_pre_access_expander

Function on_pre_access_expander 

pub fn on_pre_access_expander(
    child: impl IntoUiNode,
    handler: Handler<AccessExpanderArgs>,
) -> UiNode
Access requested to expand or collapse the widget content.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.