on_pre_access_increment

Function on_pre_access_increment 

pub fn on_pre_access_increment(
    child: impl IntoUiNode,
    handler: Handler<AccessIncrementArgs>,
) -> UiNode
Access requested to increment or decrement the widget value by steps.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.