pub fn on_pre_access_scroll( child: impl IntoUiNode, handler: Handler<AccessScrollArgs>, ) -> UiNode
Access requested a scroll command.
Note that the scroll widget already handles this event.
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident