pub fn on_pre_access_selection( child: impl IntoUiNode, handler: Handler<AccessSelectionArgs>, ) -> UiNode
Access requested a text selection.
Note that the text widget already handles this event.
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident